MethodBuilder class

Inheritance

Constructors

MethodBuilder.data({Key? key, required String route, required List<String> map, required String apiUrl, Future<List<List<String>>>? method, Image? mediaPreviewBuilder(List<String> item)?, Encoding? postBody, double? borderRadius, Widget widgetBuilder(List<String> item)?, double? widthFactor, IconData? icon, String? token, BoxDecoration? boxDecoration, EdgeInsets? padding, EdgeInsets? margin, Widget iconBuilder(List<String> item)?, WidgetType? type = WidgetType.data})
MethodBuilder.data returns very basic descriptive widget uses Title, Subtitle, Description, Icon and many more
MethodBuilder.media({Key? key, required String route, required List<String> map, required String apiUrl, Image? mediaPreviewBuilder(List<String> item)?, Future<List<List<String>>>? method, Encoding? postBody, double? borderRadius, double? widthFactor, IconData? icon, String? token, Widget widgetBuilder(List<String> item)?, BoxDecoration? boxDecoration, EdgeInsets? padding, EdgeInsets? margin, Widget iconBuilder(List<String> item)?, double? aspectRatio, Widget topRightLabel(List<String> item)?, Widget bottomRightLabel(List<String> item)?, Widget topLeftLabel(List<String> item)?, Widget timeBuilder(List<String> item)?, WidgetType? type = WidgetType.media})
MethodBuilder.media returns media widget like youtube,ott videos and streams uses Title, Subtitle, Image, Description, Icon and many more
MethodBuilder.product({Key? key, required String route, required List<String> map, required String apiUrl, required Image? mediaPreviewBuilder(List<String> item)?, Widget productDescriptionBuilder(List<String> item)?, List<String>? productPreviewBuilder(List<String> item)?, Future<List<List<String>>>? method, Encoding? postBody, Widget widgetBuilder(List<String> item)?, String? token, double? widthFactor, EdgeInsets? padding, EdgeInsets? margin, BoxDecoration? boxDecoration, WidgetType? type = WidgetType.product, double? borderRadius})
MethodBuilder.product returns product widget like amazon or paying gues rooms uses Title, Subtitle, Prices, Discounts, Icon and many more

Properties

apiUrl String
apiUrl is string of the remote server endpoint route is excluded route is string of the method that you are calling
final
aspectRatio double?
getter/setter pair
borderRadius double?
final
bottomRightLabel Widget Function(List<String> item)?
the following parameter can be used to create dynamic widget from list of string mapped from json body of the future
getter/setter pair
boxDecoration BoxDecoration?
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData?
getter/setter pair
iconBuilder Widget Function(List<String> item)?
the following parameter can be used to create dynamic widget from list of string mapped from json body of the future
getter/setter pair
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
map List<String>
map is a list of strings that are used when mapping json data from the http method example "title","subtitle","description","preview" can be used to map for { "title" : "This is title", "subtitle" : "This is subtitle", "description" : "This is description", "preview" : "https://imagenetworkurl/xyz.png" },{...},{...}
final
margin EdgeInsets?
final
mediaPreviewBuilder Image? Function(List<String> item)?
mediaPreviewBuilder is a method that acceps list of string mapped from json body using map property you can create your own image preview
getter/setter pair
method Future<List<List<String>>>?
getter/setter pair
padding EdgeInsets?
final
postBody Encoding?
postBody is json body that is to be added when using post method with response body
getter/setter pair
productDescriptionBuilder Widget Function(List<String> item)?
the following parameter can be used to create dynamic widget from list of string mapped from json body of the future
getter/setter pair
productPreviewBuilder List<String>? Function(List<String> item)?
productPreviewBuilder is a method that acceps list of string mapped from json body using map property you can create your own image preview list
getter/setter pair
productSlideBuilder Widget Function(List<String> item)?
the following parameter can be used to create dynamic widget from list of string mapped from json body of the future
getter/setter pair
route String
apiUrl is string of the remote server endpoint route is excluded route is string of the method that you are calling
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeBuilder Widget Function(List<String> item)?
the following parameter can be used to create dynamic widget from list of string mapped from json body of the future
getter/setter pair
token String?
token for header authentication with http method it uses flutter_secure_storage
final
topLeftLabel Widget Function(List<String> item)?
the following parameter can be used to create dynamic widget from list of string mapped from json body of the future
getter/setter pair
topRightLabel Widget Function(List<String> item)?
the following parameter can be used to create dynamic widget from list of string mapped from json body of the future
getter/setter pair
type WidgetType?
final
widgetBuilder Widget Function(List<String> item)?
the following parameter can be used to create dynamic widget from list of string mapped from json body of the future
getter/setter pair
widthFactor double?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<MethodBuilder>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited