mediaPreviewBuilder property
mediaPreviewBuilder is a method that acceps list of string mapped from json body using map property you can create your own image preview
Implementation
Image? Function(List<String> item)? mediaPreviewBuilder;
mediaPreviewBuilder is a method that acceps list of string mapped from json body using map property you can create your own image preview
Image? Function(List<String> item)? mediaPreviewBuilder;