productPreviewBuilder property
productPreviewBuilder is a method that acceps list of string mapped from json body using map property you can create your own image preview list
Implementation
List<String>? Function(List<String> item)? productPreviewBuilder;