topRightLabel property

Widget Function(List<String> item)? topRightLabel
getter/setter pair

the following parameter can be used to create dynamic widget from list of string mapped from json body of the future

Implementation

Widget Function(List<String> item)? widgetBuilder,
    productDescriptionBuilder,
    iconBuilder,
    timeBuilder,
    topRightLabel,
    bottomRightLabel,
    productSlideBuilder,
    topLeftLabel;