MethodBuilder class
Constructors
MethodBuilder.data ({Key ? key , required String route , required List <String > map , required String apiUrl , Future <List <List <String > > > ? method , Image ? mediaPreviewBuilder (List <String > item )?, Encoding ? postBody , double ? borderRadius , Widget widgetBuilder (List <String > item )?, num ? widthFactor , IconData ? icon , String ? token , BoxDecoration ? boxDecoration , EdgeInsets ? padding , EdgeInsets ? margin , Widget iconBuilder (List <String > item )?, WidgetType ? type = WidgetType.data })
MethodBuilder.data returns very basic descriptive widget uses Title, Subtitle, Description, Icon and many more
MethodBuilder.media ({Key ? key , required String route , required List <String > map , required String apiUrl , Image ? mediaPreviewBuilder (List <String > item )?, Future <List <List <String > > > ? method , Encoding ? postBody , double ? borderRadius , num ? widthFactor , IconData ? icon , String ? token , Widget widgetBuilder (List <String > item )?, BoxDecoration ? boxDecoration , EdgeInsets ? padding , EdgeInsets ? margin , Widget iconBuilder (List <String > item )?, double ? aspectRatio , Widget topRightLabel (List <String > item )?, Widget bottomRightLabel (List <String > item )?, Widget topLeftLabel (List <String > item )?, Widget timeBuilder (List <String > item )?, WidgetType ? type = WidgetType.media })
MethodBuilder.media returns media widget like youtube,ott videos and streams uses Title, Subtitle, Image, Description, Icon and many more
MethodBuilder.product ({Key ? key , required String route , required List <String > map , required String apiUrl , required Image ? mediaPreviewBuilder (List <String > item )?, Widget productDescriptionBuilder (List <String > item )?, List <String > ? productPreviewBuilder (List <String > item )?, Future <List <List <String > > > ? method , Encoding ? postBody , Widget widgetBuilder (List <String > item )?, String ? token , num ? widthFactor , EdgeInsets ? padding , EdgeInsets ? margin , BoxDecoration ? boxDecoration , WidgetType ? type = WidgetType.product , double ? borderRadius })
MethodBuilder.product returns product widget like amazon or paying gues rooms uses Title, Subtitle, Prices, Discounts, Icon and many more
Properties
apiUrl
→ String
apiUrl is string of the remote server endpoint route is excluded
route is string of the method that you are calling
final
aspectRatio
↔ double ?
getter/setter pair
borderRadius
→ double ?
final
bottomRightLabel
↔ Widget Function(List <String > item ) ?
the following parameter can be used to create dynamic widget from list of string mapped from json body of the future
getter/setter pair
boxDecoration
→ BoxDecoration ?
final
hashCode
→ int
The hash code for this object.
no setter inherited
icon
↔ IconData ?
getter/setter pair
iconBuilder
↔ Widget Function(List <String > item ) ?
the following parameter can be used to create dynamic widget from list of string mapped from json body of the future
getter/setter pair
key
→ Key ?
Controls how one widget replaces another widget in the tree.
final inherited
map
→ List <String >
map is a list of strings that are used when mapping json data from the http method
example
"title","subtitle","description","preview"
can be used to map for
{
"title" : "This is title",
"subtitle" : "This is subtitle",
"description" : "This is description",
"preview" : "https://imagenetworkurl/xyz.png"
},{...},{...}
final
margin
→ EdgeInsets ?
final
mediaPreviewBuilder
↔ Image ? Function(List <String > item ) ?
mediaPreviewBuilder is a method that acceps list of string mapped from json body using map property you can create your own image preview
getter/setter pair
method
↔ Future <List <List <String > > > ?
getter/setter pair
padding
→ EdgeInsets ?
final
postBody
↔ Encoding ?
postBody is json body that is to be added when using post method with response body
getter/setter pair
productDescriptionBuilder
↔ Widget Function(List <String > item ) ?
the following parameter can be used to create dynamic widget from list of string mapped from json body of the future
getter/setter pair
productPreviewBuilder
↔ List <String > ? Function(List <String > item ) ?
productPreviewBuilder is a method that acceps list of string mapped from json body using map property you can create your own image preview list
getter/setter pair
productSlideBuilder
↔ Widget Function(List <String > item ) ?
the following parameter can be used to create dynamic widget from list of string mapped from json body of the future
getter/setter pair
route
→ String
apiUrl is string of the remote server endpoint route is excluded
route is string of the method that you are calling
final
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
timeBuilder
↔ Widget Function(List <String > item ) ?
the following parameter can be used to create dynamic widget from list of string mapped from json body of the future
getter/setter pair
token
→ String ?
token for header authentication with http method it uses flutter_secure_storage
final
topLeftLabel
↔ Widget Function(List <String > item ) ?
the following parameter can be used to create dynamic widget from list of string mapped from json body of the future
getter/setter pair
topRightLabel
↔ Widget Function(List <String > item ) ?
the following parameter can be used to create dynamic widget from list of string mapped from json body of the future
getter/setter pair
type
→ WidgetType ?
final
widgetBuilder
↔ Widget Function(List <String > item ) ?
the following parameter can be used to create dynamic widget from list of string mapped from json body of the future
getter/setter pair
widthFactor
→ num ?
final
future_widget_builder 0.0.8