map property
map is a list of strings that are used when mapping json data from the http method
example
"title","subtitle","description","preview"
can be used to map for
{
"title" : "This is title",
"subtitle" : "This is subtitle",
"description" : "This is description",
"preview" : "https://imagenetworkurl/xyz.png"
},{...},{...}
Implementation
final List<String> map;